library(dplyr)
source('common.R')

anonymise <- function(anonFolder, path) {
  data <- (read.csv(path)
          %>% filter(grepl('^[0-9]+@aston.ac.uk', Author.Email))
          %>% select(-ZIP.Filename, -ZIP.SHA.256))

  # Ensure emails are a factor
  data$Author.Email <- as.factor(data$Author.Email)

  # Generate unique strings to replace the emails
  replacements <- sapply(
    seq_along(levels(data$Author.Email)),
    function(x) paste0(sample(LETTERS, 10), collapse = ""))

  # Store the lookup table for safekeeping in the private folder
  file <- basename(path)
  lookup <- data.frame(key = replacements, value = levels(data$Author.Email))
  lookup_path <- paste0(dirname(path), '/', sub('[.]csv$', '', file), '-lookup.csv')
  write.csv(lookup, lookup_path, row.names = FALSE)

  # Anonymise the student emails and save file in the public folder
  levels(data$Author.Email) <- replacements
  anonymised_path <- paste0(anonFolder, '/', sub('[.]csv$', '', file), '-anonymised.csv')
  write.csv(data, anonymised_path, row.names = FALSE)
}

anonymiseInto <- function(anonFolder) {
  function (path) { anonymise(anonFolder, path); }
}

applyFolder('202021-private', anonymiseInto('202021'))
applyFolder('202122-private', anonymiseInto('202122'))