library(dplyr)
library(ggplot2)
library(ggpattern)
library(tidyverse)
source('common.R')

counts <- read.csv('data/03-attemptsByStudent.csv')
rows <- counts %>% uncount(n)
rows$Assessment.Title <- factor(rows$Assessment.Title, levels=unique(rows$Assessment.Title))

pdf('figs/boxplot-attempts.pdf', width=9, height=5)
(ggplot(data=rows, aes(x=Assessment.Title, y=Attempt, fill=Year))
  + geom_boxplot_pattern(
    aes(pattern=Year),
    pattern_spacing=0.02,
    pattern_fill='white',
    pattern_colour='white',
    width=0.5,
    pattern_key_scale_factor=0.5
  )
  + labs(x="", y='Number of attempts')
  + scale_x_discrete(limits=rev)
  + scale_y_continuous(breaks=seq(0, 150, 10))
  + coord_flip()
  + theme_bw()
  + theme(legend.position='top')
)
dev.off()