library(dplyr)
library(tidyverse)

counts <- read.csv('data/03-attemptsByStudent.csv')
rows <- counts %>% uncount(n)

# Do a two-sided Mann-Whitney-Wilcoxon U test (null hypothesis is that
# the distributions of both populations are identical, and alternative
# hypothesis is that they are not identical).

compareYears <- function (x) {
  test <- wilcox.test(Attempt ~ Year,
              data=rows %>% filter(Assessment.Title == x[1]),
              digits.rank = 7,
              paired = FALSE)
  test$p.value
}

# Compute the third quartile for the attempts of a given lab in a given year.

thirdQuartile <- function (lab, year) {
  labdata <- rows %>% filter(Assessment.Title == lab, Year == year)
  quantile(labdata$Attempt, prob=.75)
}

labs <- data.frame(lab=unique(rows$Assessment.Title))
labs$p.value <- apply(labs, 1, compareYears)
labs$q3_202021 <- apply(labs, 1, function (x) { thirdQuartile(x[1], '2020--21') })
labs$q3_202122 <- apply(labs, 1, function (x) { thirdQuartile(x[1], '2021--22') })

write.csv(labs,
          file='data/03-attemptsByStudent-mwu.csv',
          row.names = FALSE)
