library(dplyr)
library(plyr)
library(xtable)
source('common.R')

marks <- read.csv('data/05-markKendall.csv')

# Do Kendall correlation tests
kendallByLab <- ddply(marks, .(Assessment.Title), summarise, corr=(cor.test(Attempt, Achieved.Ratio, method='kendall', alternative='greater')), names=names(corr))

# Extract p-values and estimates
pValues <- kendallByLab[kendallByLab$names == 'p.value', c('Assessment.Title', 'corr')]
colnames(pValues) <- c('Assessment.Title', 'p.value')

estimates <- kendallByLab[kendallByLab$names == 'estimate', c('Assessment.Title', 'corr')]
colnames(estimates) <- c('Assessment.Title', 'estimate')

# Merge into wide table per lab
merged <- merge(pValues, estimates)
# Fix ordering (Lab 10 should go after Lab 9)
kendall <- rbind(merged[1,], merged[3:10,], merged[2,])

printTable(kendall, 'tex/kendall-pvalues.tex')
