library(cowplot)
library(ggplot2)
library(ggpattern)

likert <- read.csv('data/06-endmoduleSurvey-likert.csv')
videoPreference <- read.csv('data/06-endmoduleSurvey-videoPreference.csv')
usedInOtherModules <- read.csv('data/06-endmoduleSurvey-usedInOtherModules.csv')

likertPlot <- (
  ggplot(likert, aes(x=question, y=n, fill=answer, label=n))
  + geom_bar_pattern(
    aes(pattern=answer, pattern_angle=answer),
    colour='black',
    pattern_fill='white',
    pattern_colour='white',
    pattern_key_scale_factor=0.25,
    position='stack',
    alpha=0.25,
    stat="identity")
  + geom_text(position=position_stack(vjust=0.5))
  + theme_bw()
  + coord_flip()
  + scale_x_discrete(limits=rev)
  + labs(x="",y="")
  + theme(legend.justification = c(0, 0.5), legend.title = element_blank(), axis.ticks.x = element_blank(), axis.text.x = element_blank(), plot.margin = margin(t=0, b=0, l=0, r=0, unit="cm"))
)

videoPreferencePlot <- (
  ggplot(videoPreference, aes(x=question, y=n, label=n, fill=answer))
  + geom_bar_pattern(
    aes(pattern=answer, pattern_angle=answer),
    colour='black',
    pattern_fill='white',
    pattern_colour='white',
    pattern_key_scale_factor=0.25,
    position='stack',
    alpha=0.25,
    stat="identity")
  + geom_text(position=position_stack(vjust=0.5))
  + theme_bw()
  + coord_flip()
  + labs(x="",y="")
  + theme(legend.justification = c(0, 0.5), legend.title = element_blank(), axis.ticks.x = element_blank(), axis.text.x = element_blank(), plot.margin = margin(t=0, b=0, l=0, r=0, unit="cm"))
)

useInOtherModulesPlot <- (
  ggplot(usedInOtherModules, aes(x=question, y=n, fill=answer, label=n))
  + geom_bar_pattern(
    aes(pattern=answer, pattern_angle=answer),
    colour='black',
    pattern_fill='white',
    pattern_colour='white',
    pattern_key_scale_factor=0.25,
    position='stack',
    alpha=0.25,
    stat="identity")
  + geom_text(position=position_stack(vjust=0.5))
  + theme_bw()
  + coord_flip()
  + labs(x="",y="")
  + theme(legend.justification = c(0, 0.5), legend.title = element_blank(), plot.margin = margin(t=0, l=0, r=0, b=0, unit="cm"))
)

pdf('figs/survey-202021-final.pdf', width=9, height=4)
plot_grid(likertPlot, NULL, videoPreferencePlot, NULL, useInOtherModulesPlot,
          ncol = 1, align = TRUE,
          rel_heights = c(1.6, -0.2, 1, -0.2, 1))
dev.off()