library(dplyr)
library(tibble)
source('common.R')

## 2019-20 CS1410: participation ratios on quizzes and assessed JavaFX lab before AutoFeedback
## (in relation to maximum engagement).

preAutofeedbackMarks <- read.csv('201920-anonymised-individual/anonymised-assignment-marks.csv')
preAutofeedbackMarks[] <- suppressWarnings(lapply(preAutofeedbackMarks, function (x) as.numeric(as.character(x))))

preAutofeedbackParticipation <- t(
  as.data.frame(t(colSums(!is.na(preAutofeedbackMarks))), row.names = NULL)
  %>% mutate(javafx.week9 = assessed.javafx.week9 + alt_ec.assessed.javafx.week9 + alt_bb.assessed.javafx.week9)
  %>% select(-assessed.javafx.week9, -alt_ec.assessed.javafx.week9, -alt_bb.assessed.javafx.week9)
)

preAutofeedbackParticipation <- tibble::rownames_to_column(
  as.data.frame(preAutofeedbackParticipation),
  'exercise'
) %>% mutate(week=as.numeric(sub('.*week([0-9]+)', '\\1', exercise)))

preAutofeedbackRatios <- data.frame(
  week=preAutofeedbackParticipation$week,
  ratioOfMax=preAutofeedbackParticipation$V1/max(preAutofeedbackParticipation$V1),
  ratioOfEnrolled=preAutofeedbackParticipation$V1/nrow(preAutofeedbackMarks),
  year='2019-20: pre-AF'
)

## 2020-21: use the final submission counts by weekday CSV from before we
## reran some of the student's submissions due to mismatched SHA256s between
## AutoFeedback and the university VLE (usually because students unnecessarily
## repackaged the same files to ZIP).

firstYearMarks <- read.csv('202021-anonymised-individual/anonymised-assignment-marks.csv')
firstYearMarks[] <- suppressWarnings(lapply(firstYearMarks, function (x) as.numeric(as.character(x))))

firstYearParticipation <- t(
  as.data.frame(t(colSums(!is.na(firstYearMarks))), row.names = NULL)
)
firstYearParticipation <- (
  tibble::rownames_to_column(as.data.frame(firstYearParticipation), 'exercise')
  %>% filter(!grepl('quiz', exercise))
  %>% mutate(week=as.numeric(sub('lab([0-9]+)[.].*', '\\1', exercise)))
)

firstYearRatios <- data.frame(
  week=firstYearParticipation$week,
  ratioOfMax=firstYearParticipation$V1/max(firstYearParticipation$V1),
  ratioOfEnrolled=firstYearParticipation$V1/nrow(firstYearMarks),
  year='2020-21'
)

## 2021-22: marks have not been imported from AF yet, use is.na check instead

secondYearAttempts <- read.csv('202122-anonymised-individual/anonymised-assignment-submissions.csv')
secondYearAttempts[] <- suppressWarnings(lapply(
  secondYearAttempts, function (x) {
    as.numeric(as.character(x) == 'Needs Marking')
  }))

secondYearParticipation <- t(
  as.data.frame(t(colSums(secondYearAttempts)), row.names = NULL)
)
secondYearParticipation <- (
  tibble::rownames_to_column(as.data.frame(secondYearParticipation), 'exercise')
  %>% mutate(week=as.numeric(sub('lab([0-9]+)[.].*', '\\1', exercise)))
  %>% filter(week!=8) # Week 8 is the prep JavaFX lab (optional)
)

secondYearRatios <- data.frame(
  week=secondYearParticipation$week,
  ratioOfMax=secondYearParticipation$V1/max(secondYearParticipation$V1),
  ratioOfEnrolled=secondYearParticipation$V1/nrow(secondYearAttempts),
  year='2021-22'
)

## Join into single table

ratios <- bind_rows(preAutofeedbackRatios, firstYearRatios, secondYearRatios)
write.csv(ratios, 'data/08-participation.csv', row.names = FALSE)