library(dplyr)
source('common.R')

data <- (
  applyFolder('202122-anonymised-individual', function (path) read.csv(path))
  %>% mutate(ratio=Achieved.Marks/Achievable.Marks)
)

levels(data$Assessment.Title)[levels(data$Assessment.Title) == 'Day::makeAppointment'] <- 'Lab 1: TDD'
levels(data$Assessment.Title)[levels(data$Assessment.Title) == 'Inheritance lab'] <- 'Lab 2: inheritance'
levels(data$Assessment.Title)[levels(data$Assessment.Title) == 'Abstract classes and interfaces'] <- 'Lab 3: interfaces 1'
levels(data$Assessment.Title)[levels(data$Assessment.Title) == 'Lab 4: Foxes and Rabbits from CRC cards'] <- 'Lab 4: interfaces 2'
levels(data$Assessment.Title)[levels(data$Assessment.Title) == 'Lab 7: Java Collections Framework and generics'] <- 'Lab 7: collections'
levels(data$Assessment.Title)[levels(data$Assessment.Title) == 'Lab 8: JavaFX preparatory lab'] <- 'Lab 8: JavaFX prep'
levels(data$Assessment.Title)[levels(data$Assessment.Title) == 'Lab 9: JavaFX assessed lab'] <- 'Lab 9: JavaFX assessed'
levels(data$Assessment.Title)[levels(data$Assessment.Title) == 'Lab 10: File I/O and Exceptions'] <- 'Lab 10: I/O and exceptions'

attemptsQuarter <- (
  data
  %>% filter(ratio>=0.25)
  %>% group_by(Assessment.Title, Author.Email)
  %>% slice_min(Attempt)
  %>% ungroup()
  %>% select(Assessment.Title, Author.Email, Attempt)
  %>% mutate(label=paste0('>= 25% marks'))
)

attemptsHalf <- (
  data
  %>% filter(ratio>=0.5)
  %>% group_by(Assessment.Title, Author.Email)
  %>% slice_min(Attempt)
  %>% ungroup()
  %>% select(Assessment.Title, Author.Email, Attempt)
  %>% mutate(label=paste0('>= 50% marks'))
)

attemptsQ3 <- (
  data
  %>% filter(ratio>=0.75)
  %>% group_by(Assessment.Title, Author.Email)
  %>% slice_min(Attempt)
  %>% ungroup()
  %>% select(Assessment.Title, Author.Email, Attempt)
  %>% mutate(label=paste0('>= 75% marks'))
)

attemptsFull <- (
  data
  %>% filter(ratio>=1)
  %>% group_by(Assessment.Title, Author.Email)
  %>% slice_min(Attempt)
  %>% ungroup()
  %>% select(Assessment.Title, Author.Email, Attempt)
  %>% mutate(label='Full marks')
)

# Separate boxplots for 25%/50%/75%/full marks

allAttempts <- bind_rows(attemptsQuarter, attemptsHalf, attemptsQ3, attemptsFull)

# Anonymised emails are not needed for plotting
write.csv(allAttempts %>% select(Assessment.Title, Attempt, label),
          'data/10-markThresholdAttempts.csv',
          row.names=FALSE)

# Summary statistics for both sets

boxplotStats <- aggregate(Attempt ~ Assessment.Title + label, allAttempts, boxplot.stats)

# Boxplot of number of additional attempts needed (paired by anonymised author email)

deltaToQuarter <- (
  attemptsQuarter
  %>% mutate(delta=Attempt, label='>= 25%')
  %>% select(Assessment.Title, Author.Email, delta, label)
)

deltaFromQuarterToHalf <- (
  attemptsQuarter
  %>% full_join(attemptsHalf, by=c('Assessment.Title', 'Author.Email'), suffix=c('.q1', '.half'))
  %>% filter(!is.na(Attempt.half))
  %>% mutate(delta=Attempt.half - Attempt.q1)
  %>% select(Assessment.Title, Author.Email, delta)
  %>% mutate(label='>= 50%')
)

deltaFromHalfToQ3 <- (
  attemptsHalf
  %>% full_join(attemptsQ3, by=c('Assessment.Title', 'Author.Email'), suffix=c('.half', '.q3'))
  %>% filter(!is.na(Attempt.q3))
  %>% mutate(delta=Attempt.q3 - Attempt.half)
  %>% select(Assessment.Title, Author.Email, delta)
  %>% mutate(label='>= 75%')
)

deltaFromQ3ToFull <- (
  attemptsQ3
  %>% full_join(attemptsFull, by=c('Assessment.Title', 'Author.Email'), suffix=c('.q3', '.full'))
  %>% filter(!is.na(Attempt.full))
  %>% mutate(delta=Attempt.full-Attempt.q3)
  %>% select(Assessment.Title, Author.Email, delta)
  %>% mutate(label='Full marks')
)

allDeltas <- bind_rows(deltaToQuarter, deltaFromQuarterToHalf, deltaFromHalfToQ3, deltaFromQ3ToFull)

# Anonymised emails are not needed for plotting
write.csv(allDeltas %>% select(Assessment.Title, delta, label),
          'data/10-markThresholdAttempts-deltas.csv',
          row.names=FALSE)