library(ggplot2)
library(ggpattern)

# Separate boxplots for 25%/50%/75%/full marks

allAttempts <- read.csv('data/10-markThresholdAttempts.csv')

pdf('figs/boxplot-markThresholdAttempts.pdf', width=9, height=6)
(
  ggplot(allAttempts, aes(x=Assessment.Title, y=Attempt, fill=label))
  + geom_boxplot_pattern(
    aes(pattern=label),
    pattern_spacing=0.02,
    pattern_fill='white',
    pattern_colour='white',
    width=0.5,
    pattern_key_scale_factor=0.5,
    outlier.shape = NA
  )
  + scale_x_discrete(limits=rev)
  + scale_y_continuous(limits=c(1, 50))
  + coord_flip()
  + labs(x="", y='First attempt reaching the mark')
  + scale_color_brewer()
  + theme_bw()
  + theme(legend.position='top', legend.title = element_blank())
)
dev.off()

# Boxplot of number of additional attempts needed (paired by anonymised author email)

allDeltas <- read.csv('data/10-markThresholdAttempts-deltas.csv')
allDeltas$Assessment.Title <- factor(allDeltas$Assessment.Title, levels=unique(allDeltas$Assessment.Title))

pdf('figs/boxplot-markThresholdDeltas.pdf', width=9, height=5)
(
  ggplot(allDeltas, aes(x=Assessment.Title, y=delta, fill=label))
  + geom_boxplot_pattern(
    aes(pattern=label, pattern_angle=label),
    pattern_spacing=0.02,
    pattern_fill='white',
    pattern_colour='white',
    width=0.75,
    pattern_key_scale_factor=0.5,
    outlier.shape = NA
  )
  + scale_x_discrete(limits=rev)
  + scale_y_continuous(limits=c(0, 30))
  + coord_flip()
  + labs(x="", y='Attempts needed')
  + theme_bw()
  + theme(legend.position='top', legend.title = element_blank())
)
dev.off()