# R project for data analysis

This is an R project analysing the engagement and performance of several cohorts of a first-year Computer Science introductory programming module (CS1410 2019-20, CS1OOP 2020-21, CS1OOP 2021-22) before and after the introduction of the [AutoFeedback](https://gitlab.com/autofeedback/) platform.

## Contents

The project includes:

* Several sets of R scripts, as `.R` files. See subsections below.
* A `data` folder with anonymised and aggregated data, used for analysis and visualisation.
* A `tex` folder with LaTeX fragments used in the paper.
* A `figs` folder with the figures used in the paper.
* A `thematic-analysis` folder with a thematic analysis of the anonymous student surveys. See its `README` for further details.

### Anonymisation

`00-anonymiseEmails.R` runs on raw exported data from AutoFeedback (from a set of `202X2Y-raw/labZZ-submissions.csv` files), to anonymise emails by replacing them with random strings, and creating a mapping file to deanonymise records if needed (which can be kept separate). The anonymised files are saved to `202X2Y-anonymised-individual` folders.

This script is included only for documentation purposes: the raw non-anonymised data files are not included in this repository to protect the privacy of the students.

### Preprocessing

The `XXa-*.R` ("side A") scripts take the individual anonymised records, and produce the files needed to drive the "side B" analyses and visualisations.

This script is included only for documentation purposes: the individual anonymised records are not included in this repository to protect the privacy of the students.

The output files produced by these scripts for the above cohorts are publicly available in the `data` folder.
These are aggregate data files which lack any form of student identity, to protect student privacy.

The `run-01-preprocessing.sh` script allows for quickly running all "side A" scripts.
As mentioned above, this is only included for documentation purposes, as the "side A" inputs are not publicly available.

### Analysis and visualisation

The `XXb-*.R` ("side B") scripts take the `.csv` files from their "A" side and create the relevant visualisation or analysis.

The `run-02-analysis.sh` script allows for quickly running all "side B" scripts.

## Dependencies

If using a Debian-based GNU/Linux distribution, please install these packages:

```shell
sudo apt-get install r-base build-essential libudunits2-dev libgdal-dev
```

The project uses [Packrat](https://rstudio.github.io/packrat/).
To restore the dependencies, run `packrat::restore()` from an R session:

```shell
R -e 'packrat::restore()'
```
