# Thematic analysis

This folder contains the results of the thematic analysis of several anonymous student surveys conducted for the CS1OOP module in the BSc Computer Science course at Aston University, during the 2020-21 and 2021-22 academic years.

## Requirements

This folder is an [Eclipse IDE project](https://www.eclipse.org/downloads/), using the [Eclipse Modeling Framework](https://www.eclipse.org/modeling/emf/) and the [Eclipse Epsilon languages](https://www.eclipse.org/epsilon/) to implement a thematic analysis workflow.

To work on this project, you will need to install Eclipse, import this project, and install Epsilon 2.4.0 or newer into Eclipse.

## Metamodel

The workflow is based on a thematic analysis metamodel (ontology), described in [`thematicAnalysis.emf`](./thematicAnalysis.emf) using the [Emfatic](https://www.eclipse.org/emfatic/) language.
It consists of the following concepts:

* An `Analysis` is made up of a `Survey` and 0+ `Theme`s.
* A `Survey` belongs to a `group` and has an `identifier`, and contains 0+ `SurveyQuestion`s and 0+ `SurveyParticipation`s.
* A `SurveyQuestion` has a `description` and a `needsRedaction` Boolean flag (if true, its answers will need to be redacted to protect student privacy).
* A `SurveyParticipation` is a collection of `SurveyAnswer`s from the same participant to the `SurveyQuestion`s.
* A `SurveyAnswer` provides a certain `text` to a `question`, and may be related to 0+ `theme`s.
* A `Theme` has a `description`, may contain 0+ `subThemes`, and may relate to 0+ `answers`.

The metamodel makes use of the EMF `eOpposite` feature to automatically maintain bidirectional links between the themes and the answers that mention them.
It is also available in XMI format from [`thematicAnalysis.ecore`](./thematicAnalysis.ecore).

## Workflow

The workflow consisted of the following steps:

1. In [`01-importFromExcel.eol`](./01-importFromExcel.eol), the raw Blackboard XLS export is turned into a model conforming to the above metamodel. Note that these raw XLS files are not publicly available to protect student privacy, as requested by the Aston University Computer Science Program Committee.
1. In [`01b-copyThemes.eol`](./01b-copyThemes.eol), some of the themes may be copied between years if the survey structure is the same, to allow for easier comparisons. This copying was done from the 2020-21 end-of-module to the 2021-22 mid-module survey, as it used the same structure.
1. The imported model was copied over to the `-analysed` folder and manually extended with the `Theme`s identified by the researcher. Three passes were done: one to identify themes, one to associate themes to answers, and one to group the "leaf" themes into broader themes.
1. In [`02-generateReport.egx`](./02-generateReport.egx), three reports were generated:
     1. For each participation, list the themes identified in each answer. The participation-based report was used to verify that no themes had been missed.
     1. For each theme, list the answers that refer to it. The theme-based report was used for the discussion in the paper.
     1. A theme-participant traceability table displays which participant mentioned which theme in their answers, and the total count.
1. In [`03-removeAnswerText.flock`](./03-removeAnswerText.flock), the answers to the free-form questions were redacted to protect student privacy. The redacted models can be made publicly available.
1. Finally, HTML reports similar to those above were generated, using the redacted models and the same `02-generateReport.egx` script.

To execute these steps, use the `.launch` files in the `launches` directory.